# this contains imports plugins that configure py.test for astropy tests.
# by importing them here in conftest.py they are discoverable by py.test
# no matter how it is invoked within the source tree.

from astropy.version import version as astropy_version
if astropy_version < '3.0':
    # With older versions of Astropy, we actually need to import the pytest
    # plugins themselves in order to make them discoverable by pytest.
    from astropy.tests.pytest_plugins import *  # noqa
else:
    # As of Astropy 3.0, the pytest plugins provided by Astropy are
    # automatically made available when Astropy is installed. This means it's
    # not necessary to import them here, but we still need to import global
    # variables that are used for configuration.
    from astropy.tests.plugins.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
 
from astropy.tests.helper import enable_deprecations_as_exceptions

# This is to figure out APLpy version, rather than using Astropy's
from . import version

import matplotlib
matplotlib.use('Agg')

try:
    packagename = os.path.basename(os.path.dirname(__file__))
    TESTED_VERSIONS[packagename] = version.version
except NameError:
    pass

# Uncomment the following line to treat all DeprecationWarnings as
# exceptions
enable_deprecations_as_exceptions()

from astropy.tests.helper import pytest


@pytest.fixture
def generate(request):
    return request.config.getoption("--generate-images-path")

# Add astropy to test header information and remove unused packages.

try:
    PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
    PYTEST_HEADER_MODULES['pyregion'] = 'pyregion'
    PYTEST_HEADER_MODULES['PyAVM'] = 'PyAVM'
    PYTEST_HEADER_MODULES['montage-wrapper'] = 'montage-wrapper'
    del PYTEST_HEADER_MODULES['h5py']
except NameError:
    pass
